@@ -16,8 +16,6 @@ class Space_AngleDecomposition(SpaceConverter):
     @staticmethod
     @register.spec("Space_AngleDecomposition", SpaceConverter)
     def spec(spec: ConverterSpec, low=None, high=None, dtype="float32"):
-        # Initialize spec with default arguments
-        spec.initialize(Space_AngleDecomposition)
         params = dict(low=low, high=high, dtype=dtype)
         spec.config.update(params)
 
@@ -34,4 +32,4 @@ class Space_AngleDecomposition(SpaceConverter):
 
     def B_to_A(self, msg):
         angle = msg.data[0]
-        return np.concatenate(([np.sin(angle), np.cos(angle)], msg.data[1:]), axis=0)
+        return np.concatenate(([np.cos(angle), np.sin(angle)], msg.data[1:]), axis=0)
